networkx 3.4.1
==============

We're happy to announce the release of networkx 3.4.1!

Maintenance
-----------

- Remove old deprecation decorator (`#7669 <https://github.com/networkx/networkx/pull/7669>`_).
- MAINT: delay loading of backend_info to after imports (`#7672 <https://github.com/networkx/networkx/pull/7672>`_).

Contributors
------------

2 authors added to this release (alphabetically):

- Dan Schult (`@dschult <https://github.com/dschult>`_)
- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)

3 reviewers added to this release (alphabetically):

- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)
- Mridul Seth (`@MridulS <https://github.com/MridulS>`_)
- Ross Barnowski (`@rossbar <https://github.com/rossbar>`_)

_These lists are automatically generated, and may not be complete or may contain duplicates._
